Module lexer

Module lexer 

Lexer for oCAS expression syntax.

The lexer recognises a minimal CAS language: integers, identifiers, arithmetic operators + - * / ^, parentheses, and commas.

Structs

LexError
Lexing error produced when input does not match any known token.

Enums

Token
A token in the oCAS expression language.

Functions

lex
Lex an input string into a vector of tokens.